@@ -3,6 +3,7 @@ import logging
 from typing import Dict, List
 
 from wykop.api.api_const import PAGE_NAMED_ARG, BODY_NAMED_ARG, FILE_POST_NAME
+from wykop.core.credentials import Credentials
 from wykop.core.requestor import Requestor
 
 log = logging.getLogger(__name__)
@@ -12,12 +13,9 @@ class WykopAPI:
     """Wykop API version 2."""
 
     def __init__(self, appkey, secretkey, account_key=None,
-                 password=None, output='', response_format='json'):
+                 output='', response_format='json'):
         self.requestor = Requestor(
-            appkey=appkey,
-            secretkey=secretkey,
-            accountkey=account_key,
-            password=password,
+            credentials=Credentials(appkey, secretkey, account_key),
             output=output,
             response_format=response_format
         )
